---
title: "Is-Ought: A Semantic Solution"
date: 2020-06-19T22:03:54Z
tags: ["hume", "is-ought dichotomy", "metaphysics"]
topics: ["philosophy"]
image: /img/lassie-and-timmy.jpg
draft: false
---

David Hume is famous for the "is-ought" problem, which comes from this famous passage, in his "Treatise on Human Nature":

> In every system of morality, which I have hitherto met with, I have always remarked, that the author proceeds for some time in the ordinary way of reasoning, and establishes the being of a God, or makes observations concerning human affairs; when of a sudden I am surprised to find, that instead of the usual copulations of propositions, is, and is not, I meet with no proposition that is not connected with an ought, or an ought not. This change is imperceptible; but is, however, of the last consequence. **For as this ought, or ought not, expresses some new relation or affirmation, it is necessary that it should be observed and explained;** and at the same time that a reason should be given, for what seems altogether inconceivable, how this new relation can be a deduction from others, which are entirely different from it. (Treatise 3.1.1)

I think an answer to Hume is not only possible, but relatively simple. First, let's dispense with the common mischaracterization of this passage. Hume never argued that "you cannot derive an ought from an is", in the sense that moral imperatives cannot be extracted from the facts of reality. Indeed, it may be that you can, and he'd probably be the first to concede the point if you had a good case. What he is telling us here, is that the classical understanding of logic doesn't seem to leave any room for "ought" statements.

What does this mean? Well, classical logic deals with static objects of thought: subjects and predicates. A subject, very simply put, is just a "thing". A pen, you, the Titanic, Lassie, couch cushions, and Beethoven's 9th Symphony are all subjects. Predicates are *what can be said about* those things. So, for example, given "The Titanic *sank in the Atlantic*", "The Titanic" is the subject, and "sank in the Atlantic" is the predicate. It is a phrase *describing* something that happened to the boat. Other examples: "You *are reading this essay*", "Lassie *always rescues Timmy*", "Beethoven's 9th Symphony *has 4 movements*". So, What can be said about a subject is not simply what is happening to it, but also what properties it exhibits. In short, anything that *describes* a state of affairs involving the subject.

From here, you can start chaining statements together: (1) Lassie is trained to rescue her friends. (2) Timmy is Lassie's friend. (3) Timmie is always getting into trouble. I think you can see where this is leading: Therefore, Lassie always rescues Timmy. But the question is *why* you saw what was coming. The full explanation for this is too complicated for a morning post. But, you can see it in the statements, as they relate to each other. Statements (1) and (2) are "linked" by the words "Lassie" and "Friend". Statements (2) and (3) are "linked" by the word "Timmie". And we have an implicit "link" between (1) and (3) in the words "rescue" and "trouble" - the former always results from the latter: Trouble begets rescue. These "links" are what is known as the "transitive" property of logic. Somehow, we know that the statements accumulate to form a complete picture. That complete picture is what is stated in the conclusion. Note that the conclusion is itself just another subject-predicate description statement itself.

What Hume was complaining about, can be illustrated by modifying our example: (1) Lassie is trained to rescue her friends. (2) Timmy is Lassie's friend. (3) Timmy has gotten himself into trouble. Therefore, Lassie should rescue Timmy. Something has changed in between statement 3 and the conclusion. Now, instead of describing a state of affairs already present, we are *prescribing* a desired state of affairs. Hume is complaining that classical logic doesn't have any mechanism to accommodate the transition from *description* to *prescription*. This has lead to all sorts of confusions. Like the one that says that Hume thought it impossible to transition from description to prescription. Or an even worse mischaracterization: that facts never imply any moral imperatives on our part (i.e. that reality is literally meaningless). Its possible that Hume argued this elsewhere. I admit I've only ever read The Treatise. But he's not making those arguments here.

In any case, the point I want to make, is that statements formulated using "should" or "ought" are not explicit statements of fact about the subjects they carry, but *implicit* statements of fact about the state of mind of the person uttering the statement. Whoever wrote down "Lassie should rescue Timmy" *wants Lassie to rescue Timmy*. But is there a way to recast the statements so that they are about their subjects, rather than their producers? Well, how about this: (1) Lassie is trained to rescue her friends. (2) Timmy is Lassie's friend. (3) Timmy had gotten himself into trouble again. (4) Lassie rescued Timmy. Therefore, Lassie is a good dog. In this case, we're no longer making a prescription, but making a value judgment in our conclusion. I should add that there is a hidden premise in this formulation as well: (1b) Good dogs obey their training. We infer from the fact that Lassie rescued her friend, that she was trained to rescue her friends, and that the standard of a good dog is to obey their training, that Lassie is therefore a good dog. This all seems to follow just fine. But this is because a value judgment is *a kind of description* (we'll set aside for now whether normative values can be real properties).

So, this is one way we can bridge the gap between "is" and "ought" - to think of "ought" statements as compressions of value judgments. In other words, using our example, (1) Lassie is trained to rescue her friends. (2) Timmy is Lassie's friend. (3) Timmy had gotten himself into trouble. (4) Lassie is a good dog, if she rescued Timmy. (5) Lassie rescued Timmy. Therefore, Lassie is a good dog. In order to make this work, we had to incorporate the use of a modus ponens, but it is entirely valid. But does this solve the problem? How much of a difference is there between a statement of value judgment, and a statement of imperative expectation? It seems to me, not much. Lassie should rescue Timmy. Okay. Or else, what? Or else, I'll judge Lassie to be a bad dog. If Lassie wants to be thought of as a good dog, Lassie will rescue Timmy. If we frame our statements this way, perhaps the gap between is and ought will be less confounding.

But if this solution is too "clever", in the sense that you'd have to cynically redefine every "ought" statement you came across, then the problem we want to solve is to make imperatives (or prescriptives) work within a framework of logic that is strictly explicit, and capable of accommodating more than just descriptive statements, *on their own terms*. We've already begun this for modal problems: the difference between what *was*, what *is*, and what *will be* can be accommodated in some forms of modern formal logic. So perhaps there is a way to do this for what should, and what shouldn't be.
