---
title: "The Parable of the Invisible Gardener"
date: 2021-05-02T23:50:09+01:00
tags: ["logical positivism", "empiricism", "falsification", "belief"]
topics: ["philosophy", "theology"]
image: /img/invisible-gardener.jpg
draft: false
---

Antony Flew is famous for a few things. Among them is an allegory he included in an essay originally published in 1955, called "Theology and Falsification". As the title implies, Flew attacks religious belief from a position that would have been familiar to someone like Bertrand Russell or A. J. Ayer, and is today is recognizable as a stock materialist criticism. Let's have a look at the parable, and Flew's reasoning from it, to see exactly why he's wrong.

> *Once upon a time two explorers came upon a clearing in the jungle. In the clearing were growing many flowers and many weeds. One explorer says, “Some gardener must tend this plot.” So they pitch their tents and set a watch. No gardener is ever seen. “But perhaps he is an invisible gardener.” So they set up a barbed-wire fence. They electrify it. They patrol with bloodhounds. (For they remember how H. G. Wells’ \*The Invisible Man\* could be both smelt and touched though he could not be seen.) But no shrieks ever suggest that some intruder has received a shock. No movements of the wire ever betray an invisible climber. The bloodhounds never give cry. Yet still the Believer is not convinced. “But there is a gardener, invisible, intangible, insensible to electric shocks, a gardener who has no scent and makes no sound, a gardener who comes secretly to look after the garden which he loves.” At last the Skeptic despairs, “But what remains of your original assertion? Just how does what you call an invisible, intangible, eternally elusive gardener differ from an imaginary gardener or even from no gardener at all?”

Flew explains the parable, thusly:

> ...to assert that such-and-such is the case is  necessarily equivalent to denying that such-and-such is not the case. Suppose, then, that we are in doubt as to what someone who gives vent to an utterance is asserting, or suppose that, more radically, we are skeptical as to whether he is really asserting anything at all. One way of trying to understand (or perhaps it will be to expose) his utterance is to attempt to find what he would regard as counting against, or as being incompatible with, it's truth...  When the sceptic in the parable asks the believer, 'just how does what you call an invisible, intangible, eternally elusive gardener differ from an imaginary gardiner at all?' he was suggesting that the believer's earlier statement had been so eroded by qualification that it was no longer an assertion at all...

In other words, the believer was making a distinction without a real difference. Or, to put Flew's claim even more plainly, if there is no real difference in the material reality of an invisible gardener, and an imaginary gardiner, then the believer hasn't made any kind of intelligible claim at all. Logical Positivists like Ayer, would have recognized this immediately as a kind of verification standard. There must be *something* in the material world we can point to, to say, "this is a garden tended by an invisible gardener", or "this is not a garden tended by an invisible gardener". If there isn't, the Positivist will insist, then the claim itself is meaningless. 

If the believer could posit a predictive theory about gardens tended by invisible gardeners (or about invisible gardeners themselves), then it would simply be a matter of setting up an experiment that showed those conditions inhering in a situation where an invisible gardener can be shown to be *not* present, in order to falsify the claim. If none of our experiments were successful, then the claim that certain gardens were tended by invisible gardeners would at least be tentatively true (on inductive grounds). This is why Flew includes details like the electric fence and the hunting dogs in the parable. These are rudimentary attempts at *confirmination* of the believer's claim (the corrollory of falsification). 

Flew's allegory has some potency. For decades, it was treated with a great deal of reverence because the idea of falsification (made famous by Popper, but applied first by the Positivists) lay at the heart of the scientific method, and that method had yielded enormously significant results in the decades leading up to 1955. What's more, if what the believer asserts is indeed a claim about some particular *phenomenon in the material world*, then he does have an issue to contend with. How would he account, for example, for Paul's conversion experience on the road to Damascus, or for a paucity of records of Pilate's encounter with Christ in the Easter narrative? Joshua at Jericho? Noah and the flood? Mary's Assumption into heaven? Or, indeed, Christ's resurrection?  

Some of these questions have indeed been dealt with empirically by historians, anthropologists, archeologists and even theologians, with mixed results, and, some apologists have spent decades making the case for the historicity of the Bible stories, again with mixed results. But such efforts are always doomed to equivocally mixed results. The reason for this, is that many of these claims *are not falsifiable claims* in the way that Flew wants them to be. 

Flew pins his critique of religious claims to the impulse to qualify:

> ...we see a child dying of inoperable cancer of the throat. His earthly father is driven frantic in his efforts to help, but his Heavenly Father reveals no obvious sign of concern. Some qualification is made: God's love is 'not merely human love' or it is 'inscrutible love', perhaps -- and we realize that such sufferings are quite compatible with the truth of the assertion that 'God loves us as a father'...

It is true that modern apologists often attempt to qualify the attribution of qualities to God. But Flew is expecting these qualifications to signify only some *literal empirical boundary*. In otherwords, some measurable difference must be present in the world, in order for the qualification to mean anything. A color red of a certain shade for example, or a temperature at certain altitudes, or an electrical charge expelled under certain conditions, or in this case, a range of human behaviors expressed under certain conditions. With this as his standard, he asks his symposium fellows, finally:

> ...What would have to occur, or to have occurred, to constitute for you, a disproof of the love of, or existence of, God?

Flew wants an event in history he can pin to a predictive theory. That's good science, but terrible theology (let alone, philosophy). However, for the Christian there is an immediately obvious answer: Rather than dying on the cross, Christ instead takes up the Devil's temptation, throws himself from the roof of the temple, and lets the angels catch him. Or, Jesus condemns his mother for lying about his adultrous origins. Or, Jesus inhabits the role of traditional Jewish Messiah, raises an army, and attempts a political coup in ancient Gallilee. Or, Christ calls down the wrath of his father on the Romans. Or, he takes all of his disciples wives as personal concubines. Or he lights Peter on fire for denying him three times before the cock crowed. Or, he spares Judas his fate. Or, he denies his own divinity. Or, he never exists at all (an assertion who's pursuit is a popular fad, today).

Any one of these things would falsify most of the fundamental claims of Judeo-Christian theology, and all of the claims of Christian theodicy. But, to accept any of this as definitive, Flew would have to first accept that there are different ways of asserting truths. Ways that go far beyond the rudimentary falsifications of empirical measurement. There are, for example, the truths of metaphor and allegory, that point to human experience that don't have empirical measurements, except by loose assocation (heart rates that are associated with romantic love, or existential fear, for example). This is especially ironic, because Flew uses allegory to make his case right in this essay. But this isn't all. There are also the truths of analogy. In the same way that both tops and electrons *really do* have "spin", and both human bodies and prisons *really do* have "cells", God *really is* a "father", and he *really does* love his creation. And, he demonstrated this in the sacrifice of his own son, at the hands of that very creation, in order to facilitate its ultimate redemption. Thus, it is not merely a "qualification" to say that God's love is "not merely human love", or that it is "inscrutible" (niether of which, is the claim of serious theologians, by the way. It is scrutible, according to Aquinas, but that's a topic for another day). Rather, it is to say that God's nature is similar to our own in some narrow sense, but only *analogously*. The intersection of an analogue is not the same thing as a qualification.

But there is a further layer to this onion I have not yet explored. Namely, that the premise of the parable is fundamentally flawed. The believer and the skeptic are arguing over the existince of some particular being who, conceivably, could be subjected to an empirical test. But, this is to equate God and his action in the world, with a finite particular being, as if God were Anatheia, and the explorers had stumbled across the Garden of the Hesperides. 

This is a common mistake among the materialists and empiricists. According to serious believers and theologians, God is not a supernatural gardener. He is the ultimate source of the fabric of reality itself. He is the ultimate ground out of which such finite things as gardens and gardeners arise. He is the the intellect that gives gardens and gardeners their pattern, and the will that gives gardens and gardeners the purpose toward which they are motivated. If Anatheia or the Garden of the Hespirides did exist, he would be the source of them both. Being the source of all material, and the source of all patterns of being that all material can inhabit, there can be no empirical test that proves or disproves his existence, because such a test would require presupposing what it is we are trying to prove. Any test attempting to prove the source of reality itself, would require us to be ouside of reality. In order to do that, we would have to make ourselves into the God we are trying to falsify. 

But, even if we take the parable at its face, there is still a problem with falsification, and this again gets to the way the parable is framed. What if we were to invert Flew's original parable? What would the implications be? [John Frame](http://www.frame-poythress.org/god-and-biblical-language-transcendence-and-immanence/) has actually already done this for us:

> Once upon a time two explorers came upon a clearing in the jungle. A man was there, pulling weeds, applying fertilizer, trimming branches. The man turned to the explorers and introduced himself as the royal gardener. One explorer shook his hand and exchanged pleasantries. The other ignored the gardener and turned away: “There can be no gardener in this part of the jungle,” he said; “this must be some trick. Someone is trying to discredit our previous findings.” They pitch camp. Every day the gardener arrives, tends the plot. Soon the plot is bursting with perfectly arranged blooms. “He’s only doing it because we’re here-to fool us into thinking this is a royal garden.” The gardener takes them to a royal palace, introduces the explorers to a score of officials who verify the gardener’s status. Then the skeptic tries a last resort: “Our senses are deceiving us. There is no gardener, no blooms, no palace, no officials. It’s still a hoax!” Finally the believer despairs: “But what remains of your original assertion? Just how does this mirage, as you call it, differ from a real gardener?”

What is immediately obvious from this inversion, is that it is possible to take any set of facts, and apply a story to them that is unfalsifiable. But, that doesn't make the story *untrue*. At worst, it makes the the truth of the story uncertain, if we assume only an empirical test could adjudicate the truth. But what test could be applied in this inverted scenario? The sceptic has rejected anything we might take as reasonably trustworthy. Given the circumstances, the evidence available, and what the two have observed in the clearing and at the palace, it makes a great deal more sense to accept the claims of the gardener and the guards, than to assume they're in some sort of elaborate Matrix-like hallucination. 

Where this applies to a belief in the existence of God, or in his love for his creation, Flew is sticking his fingers in his ears and insisting its all a hoax, like the skeptic in this inversion. Given what we have available to us in experience, reason, intuition, history, and the story of Christianity, it simply makes much more sense to accept it as true, than to assume that all of humanity is trapped in some sort of elaborate Matrix-like hallucination. 