---
title: "Why Do You Have a Right to Self Defense?"
date: 2021-11-23T23:16:16Z
tags: ["rights", "self-defense", "law", "ethics", "nihilism", "gorgias", "imago dei"]
topics: ["philosophy","politics", "theology"]
image: /img/rittenhouse.png
draft: false
---

I doubt there's anyone in the anglo-sphere this week, who isn't aware of the case of Kyle Rittenhouse in Kenosha, Wisconsin. Probably, a good chunk of Europe was paying attention to that trial, as well. Why? Because of the fundamental question that the trial symbolized, at its core. 

The principle at the center of that case was the right of self-defense. As a matter of law, that meant demonstrating in the trial that the material facts of the event conformed to Wisconsin's own statutory definition of an action that constitutes self-defense. That's one way to interpret the question 'why'. But - apart from its importance in establishing grounds for Rittenhouse's exhoneration - that's not the interpretation that *really* matters here.

The 'why' question I'm asking might be asked as a 'what' question: what is the right of self-defense? Or more deeply, what is a right? What are they, indeed. A definition of a right is something that even experienced scholars and philosophers will tell you is next to impossible to pin down. But I think we can come at the definition indirectly by asking instead, why do you have a right to anything? Or, in this case, why do you have a right to self-defense?

A common philosophical approach to this question is to begin with the ethics (just below the surface of the law). Often, you'll hear appeals to undesirable consequences, or appeals to forms of the harm principle, or the principle of reciprocity, or the right of property, as a basis for justifying the use of violence in defense of the self. There is nothing inherently wrong with making these sorts of arguments, but it misses the deeper point of the question I'm trying to ask. To put it another way, one might ask in this context why harming someone is morally wrong, why reciprocity is a good standard, or why I should accept the idea of ownership. Notice that all three of these questions could be collapsed into a single implicit question lying behind them: what's so special about you? 

At bottom, in other words, this is a metaphysical question. The reason why you have a right to self-defense is the reason why you have a right to the pursuit of happiness and the right to property. But what does that mean? Fundamentally, every rights claim is a special claim about the nature of the human person. A claim that (though modern philosophy tends to muddle this) is not available to any other creature in the world. It is the claim that human beings are imbued with a special feature that expresses itself as a moral value or entitlement to a special privilege. Sometimes we call this a "right to life". Why? 

The animal kingdom is full of examples of beasts that aggress against each other, and animals attempting to defend themselves against predators. But we wouldn't say that the Cocker Spaniel has a right to defend itself against the Rottweiler, or that the moose has a right to defend itself against the mountain lion. In these cases, the dog fight, and the ruminant fleeing from the big cat are mere matters of fact. We might express a certain distress at the violence of the situation, but this is an emotional response, not a moral one (though, sometimes it can provoke severe moral doubts, as was the case with Darwin and the Ichneumon eumerus). Even in the case of the great apes, we are prone toward pity and horror at the brutality with which troupe hierarchies are enforced, but would not ascribe moral value to the individuals involved in the conflicts, except as a function of our own projections.

What is it, exactly, that we are projecting? Some will tell you it is a veneer layer or secondary epiphenomenon of the psychological evolution of the human primate -- that the same thing we project on to 'lesser' primates, we project on to each other. But as {{< newtab title="Frans de Waal and others have discovered," url="https://www.amazon.com/Primates-Philosophers-Morality-Evolved-Princeton/dp/0691169160/">}} it is much more significant than that.  The scientists, of course, will stop short of metaphysical speculations. Though,  {{< newtab title="Brett Weinstein has recently ventured to speculate" url="https://podcasts.apple.com/gb/podcast/bret-weinstein-heather-heying-sex-religion-evolution/id1375568988?i=1000535820515" >}} about a 'layer' of reality 'below' the reality of matter in motion, even he can't bring himself to call that by its proper name. 

What am I talking about? The spirit, of course. The spirit is something more than just Aristotle's animating force, or the kinetic 'energy' of the physicists. The 'layer' of reality below matter in motion is the *immaterial*. Something religions have recognized and celebrated for ten thousand years, and which we now struggle to ignore for the sake of our 'enlightenment'. Plato and Aristotle were right to point to *nous* as the essential (aka defining) feature of the human animal - the one thing that separated it from the rest of the animal kingdom. But what they seemed to miss by only millimeters, is the fact that *nous* is not the *cause* of our uniqueness. Rather, it is the *effect* of our uniqueness. Our capacity for high reason, for deep concern about the rightness and wrongness of our actions, and for the subtle recognition of shades of beauty in the world, are not what *constitute* our value as individual souls. The capacity to grasp the transcendents is an *expression* of that value. We are the only creatures on earth that can see the *significance of creation itself*. Where does that come from? How is it that the world has not just a discernable order, but a discoverable valence, and how is it that we can indeed perceive both?

In the Christian tradition, there are answers to these questions. That 'layer below' as Brett Weinstein likes to call it, is the mind of God. The creative consciousness which we call consciousness only by analogy, because it must be radically different in kind from the *created* consciousness of material beings like ourselves -- and yet, a consciousness nonetheless, because we are able to intuit it from the facts I have been outlining briefly here. The facts of discernable order, of qualitative values discoverable in truth, goodness, and beauty, and of creatures present in the midst of all this order with the capacity to perceive it all. 

Beyond this point, philosophy cannot proceed. Like Moses condemned to remain in the desert, the intellect cannot pass beyond the veil of the 'layer below'. It can merely stand at the threshold and point the way. Philosophy's companion on the other side of that veil is religion. What the Christian faith will tell you, is that mankind is the highest expression of the love that is God himself; that each individual is a single ray of divine light penetrating this realm of material darkness; that the soul of each man is a reflection of God as he looks upon his creation and admires it in only the way that he can. It is beyond the scope of this post to get into the numerous apparently insoluble mysteries this idea gives rise to (not the least of which, that man is paradoxically *both* the most good, true, and beautiful thing in the universe, and the most most wicked, false, and depraved creature). The point here is simply this: that man's uniqueness is the *effect* of God's creative genius. Being the absolute source and unity of the good, the true, and the beautiful, he is the ground of all value. The fact that we are able to share the perception of these realities with the creator of them, means that we are, even as finite creatures -- indeed, animals -- yet uniquely valuable among creatures. It is that link with the absolute value of God, that is the ground of our moral value. 

Various denominations of Christianity will give you different specific explanations for the duty of care that this all implies. For example, John Locke argued from the doctrine of the Imago Dei (the latin phrase for what I have described above), in combination with Calvinist interpretations of Genesis, that each man was the property of God, in the same way that the products of a craftsman were the property of the craftsman, because of the value imputed to the product by the craftsman. Given our capacity for rational deliberation,  and the burden of original sin (in which we were tasked to work the land as punishment for our disobedience), this meant that each of us was a kind of stewart of God's creation. We are tasked with improving it in whatever way our own talents and abilities enabled. To damage or destroy what God created is thus a great sin, because it is rebellion against that duty of care and to incur a debt that could only be repaid by the grace of God himself. Since man is the greatest of the masterpeices of creation, threatening a man's life was thus the worst of sins. By reciprocal inference, therefore, each man not only had a duty of care to others, but a duty of care to himself as well. Only God had the absolute liberty to grant or to take away life, as he saw fit. Where a man faced the loss of his life at another man's hand, therefore, his first duty was to preserve his own, if he took God's charge seriously.

Other explanations from theology and scripture are available. Some with very different routes from the Imago Dei, to self-defense. But Locke's happens to be the one most consonant with our own legal tradition, in America. But they all ultimately begin with the Imago Dei. This point cannot be stressed enough. If we refuse to look beyond the veil of matter-in-motion, then there can be no final answer as to whether a man has any rights at all, let alone the right of self-defense. Because they all rest in the absolute value of the creative consciousness that gave birth to the world in the first place. Absent that, we are doomed to squabble with each other perpetually, over what matters. This is because (as Ayn Rand recognized), beyond the point of sustaining life itself, all material values are instrumental and subjective. As she put it, "of value to whom, and for what?". In otherwords, individual men will have their own individual purposes, and their values will both inform and serve those ends, and finally, a Nietzschean world of men like Callicles from the Gorgias will make lesser men a means to their own ends. 

This may seem like I'm making an argument to undesirable consequences. In one sense, it is. But there is an underlying point here. The only way we can recognize the picture I've painted as 'undesirable' in the first place, is if we recognize that there is *in fact* an order to the world that is *better* and an order to the world that is *worse*. Nietzsche famously argued precisely that he wanted a 'transvaluation of all values'. In other words, his goal was the *complete inversion* of what he already understood to be the good and the bad. He made deranged claims from a florid and fantastical reading of history, that it was the Jews, and later more effectively the Christians, who had falsely inverted the reality of good and evil, and that he alone could see this from his Hyperborian perch, and was uniquely positioned to right the ship, as it were. This disturbed German sausage churning of Plato was what led (at least in part) to the Nazi annihilation of six million Jews, and an entire nation monomaniacally obsessed with being rulers over the entire earth. 

In God's absence, men seek his power for themselves, because they crave his ordering authority, and where they cannot see his will enacting that order, they will claim it for themselves. In seeking his power, they seek the privilege that comes with that power, substituting their own ends as the new ordering authority. Thus, each of us becomes a means to each other's ends. This world full of particular, finite wills all clamoring to be the absolute, ends ironically not in a new order, but in self-annihilation. However, God is never really absent. The Nietzschean has merely gouged out his own eyes, and madly shouted that he has killed God, because the empty eye sockets cannot perceive him anymore. 

The rioters in Kenosha that night in August are those self-mutilated Nietzscheans. Kyle Rittenhouse gave them a target. Killing him would further their blind obsession for the transvaluation of all values. His murder would incrementally reduce the possibility that they might have to face the truth that they were wrong to gouge out their own eyes. Had they succeeded, they would also have made it even harder for an already half-blind population to find their way to the same truth. This is yet another reason why Kyle was right to protect himself that night. Because in doing so, he has radically improved the chance that many more of the blind will soon see again. 

Thank God for Kyle Rittenhouse.
